==> devops-client-java-1.0.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1ImageRegistrySpecFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Fluent;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

public interface V1alpha1ImageRegistrySpecFluent<A extends V1alpha1ImageRegistrySpecFluent<A>> extends Fluent<A>{


    public A addToData(String key,String value);
    public A addToData(Map<String,String> map);
    public A removeFromData(String key);
    public A removeFromData(Map<String,String> map);
    public Map<String,String> getData();
    public A withData(Map<String,String> data);
    public Boolean hasData();
    
/**
 * This method has been deprecated, please use method buildHttp instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1HostPort getHttp();
    public V1alpha1HostPort buildHttp();
    public A withHttp(V1alpha1HostPort http);
    public Boolean hasHttp();
    public V1alpha1ImageRegistrySpecFluent.HttpNested<A> withNewHttp();
    public V1alpha1ImageRegistrySpecFluent.HttpNested<A> withNewHttpLike(V1alpha1HostPort item);
    public V1alpha1ImageRegistrySpecFluent.HttpNested<A> editHttp();
    public V1alpha1ImageRegistrySpecFluent.HttpNested<A> editOrNewHttp();
    public V1alpha1ImageRegistrySpecFluent.HttpNested<A> editOrNewHttpLike(V1alpha1HostPort item);
    public Boolean isPublic();
    public A withPublic(Boolean _public);
    public Boolean hasPublic();
    public A withNewPublic(String arg1);
    public A withNewPublic(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSecret instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1SecretKeySetRef getSecret();
    public V1alpha1SecretKeySetRef buildSecret();
    public A withSecret(V1alpha1SecretKeySetRef secret);
    public Boolean hasSecret();
    public V1alpha1ImageRegistrySpecFluent.SecretNested<A> withNewSecret();
    public V1alpha1ImageRegistrySpecFluent.SecretNested<A> withNewSecretLike(V1alpha1SecretKeySetRef item);
    public V1alpha1ImageRegistrySpecFluent.SecretNested<A> editSecret();
    public V1alpha1ImageRegistrySpecFluent.SecretNested<A> editOrNewSecret();
    public V1alpha1ImageRegistrySpecFluent.SecretNested<A> editOrNewSecretLike(V1alpha1SecretKeySetRef item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface HttpNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1HostPortFluent<V1alpha1ImageRegistrySpecFluent.HttpNested<N>>{

        
    public N and();    public N endHttp();
}
    public interface SecretNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1SecretKeySetRefFluent<V1alpha1ImageRegistrySpecFluent.SecretNested<N>>{

        
    public N and();    public N endSecret();
}


}

==> devops-client-java-1.0.7.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1ImageRegistrySpecFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Fluent;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

public interface V1alpha1ImageRegistrySpecFluent<A extends V1alpha1ImageRegistrySpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBindingPolicy instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1ImageRegistryBindingPolicy getBindingPolicy();
    public V1alpha1ImageRegistryBindingPolicy buildBindingPolicy();
    public A withBindingPolicy(V1alpha1ImageRegistryBindingPolicy bindingPolicy);
    public Boolean hasBindingPolicy();
    public V1alpha1ImageRegistrySpecFluent.BindingPolicyNested<A> withNewBindingPolicy();
    public V1alpha1ImageRegistrySpecFluent.BindingPolicyNested<A> withNewBindingPolicyLike(V1alpha1ImageRegistryBindingPolicy item);
    public V1alpha1ImageRegistrySpecFluent.BindingPolicyNested<A> editBindingPolicy();
    public V1alpha1ImageRegistrySpecFluent.BindingPolicyNested<A> editOrNewBindingPolicy();
    public V1alpha1ImageRegistrySpecFluent.BindingPolicyNested<A> editOrNewBindingPolicyLike(V1alpha1ImageRegistryBindingPolicy item);
    public A addToData(String key,String value);
    public A addToData(Map<String,String> map);
    public A removeFromData(String key);
    public A removeFromData(Map<String,String> map);
    public Map<String,String> getData();
    public A withData(Map<String,String> data);
    public Boolean hasData();
    
/**
 * This method has been deprecated, please use method buildHttp instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1HostPort getHttp();
    public V1alpha1HostPort buildHttp();
    public A withHttp(V1alpha1HostPort http);
    public Boolean hasHttp();
    public V1alpha1ImageRegistrySpecFluent.HttpNested<A> withNewHttp();
    public V1alpha1ImageRegistrySpecFluent.HttpNested<A> withNewHttpLike(V1alpha1HostPort item);
    public V1alpha1ImageRegistrySpecFluent.HttpNested<A> editHttp();
    public V1alpha1ImageRegistrySpecFluent.HttpNested<A> editOrNewHttp();
    public V1alpha1ImageRegistrySpecFluent.HttpNested<A> editOrNewHttpLike(V1alpha1HostPort item);
    public Boolean isPublic();
    public A withPublic(Boolean _public);
    public Boolean hasPublic();
    public A withNewPublic(String arg1);
    public A withNewPublic(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSecret instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1SecretKeySetRef getSecret();
    public V1alpha1SecretKeySetRef buildSecret();
    public A withSecret(V1alpha1SecretKeySetRef secret);
    public Boolean hasSecret();
    public V1alpha1ImageRegistrySpecFluent.SecretNested<A> withNewSecret();
    public V1alpha1ImageRegistrySpecFluent.SecretNested<A> withNewSecretLike(V1alpha1SecretKeySetRef item);
    public V1alpha1ImageRegistrySpecFluent.SecretNested<A> editSecret();
    public V1alpha1ImageRegistrySpecFluent.SecretNested<A> editOrNewSecret();
    public V1alpha1ImageRegistrySpecFluent.SecretNested<A> editOrNewSecretLike(V1alpha1SecretKeySetRef item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface BindingPolicyNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1ImageRegistryBindingPolicyFluent<V1alpha1ImageRegistrySpecFluent.BindingPolicyNested<N>>{

        
    public N and();    public N endBindingPolicy();
}
    public interface HttpNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1HostPortFluent<V1alpha1ImageRegistrySpecFluent.HttpNested<N>>{

        
    public N and();    public N endHttp();
}
    public interface SecretNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1SecretKeySetRefFluent<V1alpha1ImageRegistrySpecFluent.SecretNested<N>>{

        
    public N and();    public N endSecret();
}


}
